@@ -37,6 +37,9 @@ QList<SearchProvider*> WrPlugin::searchProviders() {
         allProviders.append(new SearchProvider("Amazon UK", "http://www.amazon.co.uk/s/ref=nb_sb_noss?url=search-alias%3Daps&field-keywords=%s"));
         allProviders.append(new SearchProvider("Best Game Price UK", "http://www.best-game-price.co.uk/search-Keywords/1-/300703/%s"));
         allProviders.append(new SearchProvider("Check UPC", "http://www.checkupc.com/search.php?keyword=%s"));
+        allProviders.append(new SearchProvider("Froogle", "http://www.google.com/products?q=%s"));
+        allProviders.append(new SearchProvider("UPC Database", "http://www.upcdatabase.com/item/%s"));
+        allProviders.append(new SearchProvider("EAN Search", "http://www.ean-search.org/perl/ean-search.pl?q=%s"));
         setSearchProviders(allProviders);
         settings->setValue("defaultValuesCreated", true);
     } else {
