@@ -24,13 +24,8 @@ void WrSink::clickAction(QWidget *parentWindow) {
     win->show();
 }
 
-void WrSink::barcodeAnalysed(QString barcodeType, QString barcodeData) {
-    ready = true;
-    plugin->barcodeText = barcodeData;
-}
-
 bool WrSink::isReady() {
-    return ready;
+    return true;
 }
 
 void WrSink::setPlugin(WrPlugin *plugin) {
