@@ -21,8 +21,6 @@ public:
     void setPlugin(WrPlugin* plugin);
     // other
     //QString url;
-private slots:
-    void barcodeAnalysed(QString barcodeType, QString barcodeData);
 private:
     bool ready;
     QString buttonText;
